@@ -23,6 +23,22 @@ extern "C" {
     };
 #endif
 
+typedef struct 
+{
+    struct nifti_1_header hdr0;
+
+    size_t         imgsz;
+    unsigned char *imgM;
+
+    struct TDICOMdata tdicomData;
+
+    struct TDTI *tdti;
+    int numDti;
+} MRIFSSTRUCT;
+
+MRIFSSTRUCT* nii_getMrifsStruct();
+void nii_clrMrifsStruct();
+
 #define kNAME_CONFLICT_SKIP 0 //0 = write nothing for a file that exists with desired name
 #define kNAME_CONFLICT_OVERWRITE 1 //1 = overwrite existing file with same name
 #define kNAME_CONFLICT_ADD_SUFFIX 2 //default 2 = write with new suffix as a new file
@@ -34,6 +50,8 @@ extern "C" {
 #define kSaveFormatNIfTI 0
 #define kSaveFormatNRRD 1
 #define kSaveFormatMGH 2
+#define kSaveFormatJNII 3
+#define kSaveFormatBNII 4
 
 #define MAX_NUM_SERIES 16
 
@@ -59,6 +77,7 @@ extern "C" {
     void readIniFile (struct TDCMopts *opts, const char * argv[]);
     int nii_saveNIIx(char * niiFilename, struct nifti_1_header hdr, unsigned char* im, struct TDCMopts opts);
     int nii_loadDir(struct TDCMopts *opts);
+    int nii_loadDirCore(char *indir, struct TDCMopts* opts);
     void nii_SaveBIDS(char pathoutname[], struct TDICOMdata d, struct TDCMopts opts, struct nifti_1_header *h, const char * filename);
     int nii_createFilename(struct TDICOMdata dcm, char * niiFilename, struct TDCMopts opts);
     void  nii_createDummyFilename(char * niiFilename, struct TDCMopts opts);
