@@ -11,9 +11,10 @@
 	#ifdef USING_R
 		#define R_USE_C99_IN_CXX
 		#include <R_ext/Print.h>
-		#define printMessage(...) { Rprintf("[dcm2niix info] "); Rprintf(__VA_ARGS__); }
-		#define printWarning(...) { Rprintf("[dcm2niix WARNING] "); Rprintf(__VA_ARGS__); }
-		#define printError(...) { Rprintf("[dcm2niix ERROR] "); Rprintf(__VA_ARGS__); }
+		#define printMessage(...)   do { Rprintf("[dcm2niix info] "); Rprintf(__VA_ARGS__); } while (0)
+		#define printWarning(...)   do { Rprintf("[dcm2niix WARNING] "); Rprintf(__VA_ARGS__); } while (0)
+		#define printError(...)     do { Rprintf("[dcm2niix ERROR] "); Rprintf(__VA_ARGS__); } while (0)
+		#define printError(frac)     do { Rprintf("[dcm2niix PROGRESS] %g", frac); } while (0)
 	#else
 		#ifdef myUseCOut
 			//for piping output to Qtextedit
@@ -32,10 +33,12 @@
 			  delete[] buf;
 			}
 			#define printError(...) do { printMessage("Error: "); printMessage(__VA_ARGS__);} while(0)
+			#define printProgress(frac) do { printMessage("Progress: %g\n", frac);} while(0)
 		#else
 			#include<stdio.h>
 			#define printMessage printf
 			//#define printMessageError(...) fprintf (stderr, __VA_ARGS__)
+			#define printProgress(frac) do { printMessage("Progress: %g\n", frac);} while(0)
 			#ifdef myErrorStdOut //for XCode MRIcro project, pipe errors to stdout not stderr
 				#define printError(...) do { printMessage("Error: "); printMessage(__VA_ARGS__);} while(0)
 			#else
